#!/usr/bin/env python

# to run, say "python readcsv.py" at command line

import csv
import sys
import numpy as np
import os
import shutil
import math

msun = 1.9892e33
rsun = 6.9598e10
mjup = 1.8986e30
rjup = 7.192e9 # equatorial radius
mearth = 5.97e27
au = 1.496e13
sigma=5.67e-5

# logfile says is the run finished ok or not
# fail means either crash, or don't evolve to the end time

logfile='logfile'
ff=open(logfile,'w')

# paramfile is a list of parameters used in each run
#paramfile='paramfile'
#gg=open(paramfile,'w')

# initial radius in jupiter units
r_jup = 5.0

# core properties
rhocore = 10.0		# in g/cc
mcore_earth_grid = [ 0.0 ]

# evolution parameters
#m_grid_baraffe_sun = [0.0005, 0.0010, 0.0020, 0.0030, 0.0040, 0.0050, 0.0060, 0.0070, 0.0080, 0.0090, 0.0100, 0.0120, 0.0150, 0.0200]
mmin=0.2 # 0.41382 # 0.5
mmax=20.0 # 0.50 # 20.0
nm= 40 # 40
Teq = 0.0
dayflux = 4.0 * sigma * Teq**4					# parameter entered is dayside flux
col=250.0
maxage = 2.e10

strTeq=str(Teq)

for mcore_earth in mcore_earth_grid:				# outer loop of core masses
	if mcore_earth > 0:
		 add_core = True
	else:
		add_core = False
	mcore_jup=mcore_earth * mearth / mjup
	mcore_sun = mcore_earth * mearth / msun
	rcore_jup = (3.0*mcore_earth * mearth / 4.0 / 3.14 / rhocore)**(1.0/3.0) / rjup

	# inner loop of total masses
	dlgm=math.log10(mmax/mmin)/(nm-1.0)
	for i in range(7,8) : # range(0,nm):					# inner loop over mass
		print "i,nm=",i,nm
		m_tot_jup = mmin*10.0**(dlgm*i)
       		m_jup = m_tot_jup - mcore_jup

#	i=0
#	for m_tot_sun in m_grid_baraffe_sun:
#		m_tot_jup = m_tot_sun * msun / mjup
#		m_jup = m_tot_jup - mcore_jup

        	nstep = 0 
        	m = m_jup * mjup
        	r = r_jup * rjup
        	strm=str(m_tot_jup)[0:5]
		strmcore = str(mcore_earth)[0:5]
        	inlist = "inlist_" + strm + "_Mj_" + strmcore + "_Me_" +  "init"
       		smwtfname = "init_" + strm + "_Mj_" + strmcore + "_Me" + ".mod"
       		f = open('inlist_base_1', 'r')
        	g = f.read()
        	f.close()
        	g = g.replace("<<r>>",str(r))
		g = g.replace("<<m>>",str(m))		# for create initial model
        	#g = g.replace("<<m>>",str(m_jup*mjup/msun)) # for pms model
        	g = g.replace("<<nstep>>",str(nstep))
        	g = g.replace("<<smwtfname>>", '"' + smwtfname + '"' )
       		h = open(inlist, 'w')
        	h.write(g)
        	h.close()
        	shutil.copyfile(inlist,"inlist_project")

        	print "-------------------------------------------------------------"

        	print "create initial model:"
       		print "M/Msun=",m/msun
        	print "R/Rsun=",r/rsun
        	print "nstep=",nstep
		print "inlist=",inlist
		print "save model with name ",smwtfname
        	os.system('./rn')

        	if os.path.exists(smwtfname):
                	s= 'mass=' + str(m_jup) + ": init ok\n"
			ff.write(s)
        	else:
                	s= 'mass=' + str(m_jup) + ": init failed\n"
        		ff.write(s)
			continue	# failed, so can't use this mass
        	print s

        	print "-------------------------------------------------------------"
        	print

		if add_core:					# add core

	                inlist = "inlist_" + strm + "_Mj_" + strmcore + "_Me_" +  "addcore"
			loadfile = smwtfname
			smwtfname = "addcore_" + strm + "_Mj_" + strmcore + "_Me" + ".mod"
	                f = open('inlist_base_2', 'r')
       	        	g = f.read()
                	f.close()
                	g = g.replace("<<loadfile>>",'"' + loadfile + '"')
                        g = g.replace("<<smwtfname>>", '"' + smwtfname + '"' )
                	g = g.replace("<<new_core_mass>>",str(mcore_sun))
               		g = g.replace("<<core_avg_rho>>",str(rhocore))
                	h = open(inlist, 'w')
                	h.write(g)
                	h.close()
                	shutil.copyfile(inlist,"inlist_project")

			print "-------------------------------------------------------------"
			print "add core:"
			print "core mass/Mearth=",mcore_earth
			print "core radius/Rjup=",rcore_jup
        	        print "inlist=",inlist
			print "load file with name ",loadfile
	                print "save model with name ",smwtfname

	                os.system('./rn')

        	        if os.path.exists(smwtfname):
                	        s= "mass=" + str(m_jup) + "core mass" + str(mcore_earth) +  ": add core ok\n"
                       		ff.write(s)
                	else:
                        	s= 'mass=' + str(m_jup) + "core mass" + str(mcore_earth) +  ": add core failed\n"
                        	ff.write(s)
                        	continue        # failed, so can't use this run
                	print s

			print 
	                print "-------------------------------------------------------------"


        	# evolve for age of planet

                loadfile = smwtfname
                smwtfname = "evolve_" + strm + "_Mj_" + strmcore + "_Me_" + strTeq + "_K" + ".mod"
                inlist = "inlist_" + strm + "_Mj_" + strmcore + "_Me_" + strTeq + "_K" + "evolve"

        	f = open( 'inlist_base_3' , 'r')
        	g = f.read()
        	f.close()

        	g = g.replace("<<flux>>",str(dayflux))
        	g = g.replace("<<col>>",str(col))
        	g = g.replace("<<maxage>>",str(maxage))
        	g = g.replace("<<loadfile>>", '"' + loadfile + '"' )
        	g = g.replace("<<smwtfname>>", '"' + smwtfname + '"' )


		print "-------------------------------------------------------------"
		print "evolve:"
                print "M/Msun=",m/msun
                print "R/Rsun=",r/rsun
                print "core mass/Mearth=",mcore_earth
                print "core radius/Rjup=",rcore_jup
		print "Teq[K]=",Teq
		print "dayside flux[cgs]=",dayflux
		print "col[g/cm^2]",col
                print "inlist=",inlist
                print "load file with name ",loadfile
                print "save model with name ",smwtfname

        	h = open(inlist, 'w')
        	h.write(g)
        	h.close()
        	shutil.copyfile(inlist,"inlist_project")
       		os.system('./rn')
        	if os.path.exists(smwtfname):
                	s= 'mass=' + str(m_jup) + "core mass" + str(mcore_earth) + "Teq" +  strTeq + "K" +  ": evol ok\n"
        	else:
                	s= 'mass=' + str(m_jup) + "core mass" + str(mcore_earth) + "Teq" +  strTeq + "K" +  ": evol failed\n"
        	ff.write(s)
        	print s

        	#hfile = "history_" + strm + "_Mj_" + strmcore + "_Me_" + strTeq + "_K" + ".data"
		hfile = "history_" + str(i) + ".data"
        	shutil.copyfile("LOGS/history.data",hfile)

        	print "-------------------------------------------------------------"
        	print
        	# end run for this planet

		# use this only for baraffe!!!
		#i=i+1


ff.close()
#gg.close()

