from pylab import *
from math import sqrt
from numpy import genfromtxt
from matplotlib import rc
rc('font',**{'family':'serif','serif':['Palatino']})
rc('text',usetex=True)
fontsize=22

Ro=6.9598e10
Mo=1.9891e33
G=6.67384e-8


d1gyr=genfromtxt('a01dsep.data',names=True,dtype=None,skip_header=8)
d5gyr=genfromtxt('a05dsep.data',names=True,dtype=None,skip_header=8)

m1gyr=genfromtxt('a01mesa.data',names=True,dtype=None,skip_header=3)
m5gyr=genfromtxt('a05mesa.data',names=True,dtype=None,skip_header=3)

data1=genfromtxt('torres.data',names=True,dtype=None,skip_header=0)
data2=genfromtxt('carter.data',names=True,dtype=None,skip_header=0)
data3=genfromtxt('irwin.data',names=True,dtype=None,skip_header=0)
data4=genfromtxt('bass.data',names=True,dtype=None,skip_header=0)

def plot_dsep(table,line,label):
    X=[]; Y=[]
    #fill X and Y arrays
    for i in range(len(table)):
        X.append(table[i][1])
        Y.append(table[i][3])

    for i in range(len(Y)):
        Y[i] = sqrt(G*X[i]*Mo/10**Y[i])/Ro

    plot(X,Y,line,label=label,lw=2)
    return 0

def plot_mesa(table,line,label):
    X=[]; Y=[];
    for i in range(len(table)):
        X.append(table[i][1])
        Y.append(table[i][17])

    for i in range(len(table)):
        Y[i] = 10**Y[i]

    plot(X,Y,line,label=label,lw=2)
    return 0

def plot_data(table,label):
    X=[]; Xe=[]; Y=[]; Ye=[];
    for i in range(len(table)):
        X.append(table[i][0])
        Xe.append(table[i][1])
        Y.append(table[i][2])
        Ye.append(table[i][3])
    #scatter(X,Y)
    errorbar(X,Y, xerr=Xe, yerr=Ye, fmt='ko',label=label)
    return 0

figure(1,figsize=[7,7])
clf()

xmin=0.1
xmax=1.0
ymin=0.1001
ymax=1.0

xticks(fontsize=fontsize)
yticks(fontsize=fontsize)
ylabel(r'$R (R_{\odot})$',fontsize=fontsize)
xlabel(r'$M (M_{\odot})$',fontsize=fontsize)

plot_mesa(m1gyr,label=r'MESA, 1 Gyr',line='r-')
plot_mesa(m5gyr,label=r'MESA, 5 Gyr',line='b-')

plot_dsep(d1gyr,label='DSEP, 1 Gyr',line='r--')
plot_dsep(d5gyr,label='DSEP, 5 Gyr',line='b--')

plot_data(data1,label='') #,label='Torres et al. (2010)')
plot_data(data2,label='')
plot_data(data3,label='')
plot_data(data4,label='')


xlim((xmin,xmax))
ylim((ymin,ymax))
legend(loc=4,prop={'size':fontsize-2},frameon=False)
show()
savefig('DSEP_MESA_MR.pdf')
savefig('DSEP_MESA_MR.eps')
