from pylab import *
from numpy import loadtxt
from matplotlib import rc
rc('font',**{'family':'serif','serif':['Palatino']})
rc('text',usetex=True)
fontsize1=20
fontsize2=22

#OPAL opacity files: column 0(logT), column 13(logR=-5)
k2m2=loadtxt('gs98_z2m2_x70.data',skiprows=7,usecols=(0,13))
k1m2=loadtxt('gs98_z1m2_x70.data',skiprows=7,usecols=(0,13))
k4m3=loadtxt('gs98_z4m3_x70.data',skiprows=7,usecols=(0,13))
k1m3=loadtxt('gs98_z1m3_x70.data',skiprows=7,usecols=(0,13))
k1m4=loadtxt('gs98_z1m4_x70.data',skiprows=7,usecols=(0,13))

#MESA profiles for 60 Msun ZAMS models
m2m2=loadtxt('z2m2_profile.data',skiprows=6,usecols=(1,35))
m1m2=loadtxt('z1m2_profile.data',skiprows=6,usecols=(1,35))
m4m3=loadtxt('z4m3_profile.data',skiprows=6,usecols=(1,35))
m1m3=loadtxt('z1m3_profile.data',skiprows=6,usecols=(1,35))
m1m4=loadtxt('z1m4_profile.data',skiprows=6,usecols=(1,35))

#reusable plot command
def plot_one(table,log,color,label):
    X=[]; Y=[]
    for i in range(len(table)):
        X.append(table[i][0])
        if log:
            Y.append(10**table[i][1])
        else:
            Y.append(table[i][1])
    plot(X,Y,lw=2.5,color=color,label=label)
    return 0


# Plot figure
figure(1,figsize=[15,7])
clf()

subplot(121)
#title(r'Table data for $X=0.7$ and $\log(\rho/{T_6}^3)=-5$',fontsize=fontsize,verticalalignment='bottom')
axis([4.75,7,0,3])
xlabel(r'$\log T$', fontname='serif', fontsize=fontsize2)
ylabel(r'$\kappa$ (cm$^2$ g$^{-1}$)',fontname='serif',fontsize=fontsize2)
xticks(fontname='serif',fontsize=fontsize2)
yticks(fontname='serif',fontsize=fontsize2)
plot_one(k2m2,True,'red','Z=0.02')
plot_one(k1m2,True,'green','Z=0.01')
plot_one(k4m3,True,'blue','Z=0.004')
plot_one(k1m3,True,'purple','Z=0.001')
plot_one(k1m4,True,'black','Z=0.0001')
legend(prop={'size':fontsize2},frameon=False)
text(4.85,0.1,r'OPAL: $X=0.7$, $\log(\rho/{T_6}^3)=-5$',fontsize=fontsize1)

subplot(122)
#title(r'$60\,M_{\odot}$ ZAMS model profiles',fontsize=fontsize,verticalalignment='bottom')
axis([4.75,7,0,2])
xlabel(r'$\log T$', fontname='serif', fontsize=fontsize2)
ylabel(r'$\kappa$ (cm$^2$ g$^{-1}$)',fontname='serif',fontsize=fontsize2)
xticks(fontname='serif',fontsize=fontsize2)
yticks(fontname='serif',fontsize=fontsize2)
plot_one(m2m2,False,'red','Z=0.02')
plot_one(m1m2,False,'green','Z=0.01')
plot_one(m4m3,False,'blue','Z=0.004')
plot_one(m1m3,False,'purple','Z=0.001')
plot_one(m1m4,False,'black','Z=0.0001')
legend(prop={'size':fontsize2},frameon=False)
text(4.85,0.07,r'$60\,M_{\odot}$ ZAMS profiles',fontsize=fontsize1)
show()
savefig('kappa.eps')
savefig('kappa.pdf')
